extensions = ['sphinx.ext.doctest']

project = 'test project for doctest'
root_doc = 'doctest'
source_suffix = {
    '.txt': 'restructuredtext',
}
exclude_patterns = ['_build']
